<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../../forms/fontdialog.ui" line="14"/>
        <location filename="../../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Выберите шрифт терминала</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Кегль:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="79"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="vanished">Переименовать сессию</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="171"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Нажмите &quot;%1&quot; чтобы увидеть терминал.</translation>
    </message>
    <message>
        <source>&amp;Clear Current Tab</source>
        <translation type="vanished">&amp;Очистить текущую вкладку</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="218"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Следующая вкладка</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="221"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Предыдущая вкладка</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="224"/>
        <source>Move Tab &amp;Left</source>
        <translation>Сдвинуть вкладку в&amp;лево</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="227"/>
        <source>Move Tab &amp;Right</source>
        <translation>Сдвинуть вкладку в&amp;право</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="232"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Разделить терминал по &amp;горизонтали</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="235"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Разделить терминал по &amp;вертикали</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="240"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Закрыть подтерминал</translation>
    </message>
    <message>
        <source>N&amp;ext Subterminal</source>
        <translation type="vanished">С&amp;ледующий подтерминал</translation>
    </message>
    <message>
        <source>P&amp;revious Subterminal</source>
        <translation type="vanished">П&amp;редыдущий подтерминал</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="211"/>
        <source>&amp;Clear Active Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <source>&amp;Top Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="246"/>
        <source>&amp;Bottom Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="249"/>
        <source>L&amp;eft Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="252"/>
        <source>R&amp;ight Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="259"/>
        <source>Copy &amp;Selection</source>
        <translation>Скопировать &amp;выделенное</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Paste Clip&amp;board</source>
        <translation>Вставить из буф&amp;ера</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="265"/>
        <source>Paste S&amp;election</source>
        <translation>Вставить в&amp;ыделенное</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="268"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;Увеличить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="271"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Уменьшить</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="274"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;Сбросить увеличение</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="279"/>
        <source>&amp;Find...</source>
        <translation>&amp;Найти...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="287"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Сохранить сеанс</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="293"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Загрузить сеанс</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="300"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Показать строку меню</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="305"/>
        <source>Rename session</source>
        <translation type="unfinished">Переименовать сессию</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="313"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Новая вкладка</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="317"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Новая вкладка из &amp;шаблонов</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="318"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;терминал</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="320"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;горизонтальных терминала</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="322"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;вертикальных терминала</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="324"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 терминал&amp;а</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="330"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="333"/>
        <source>&amp;New Window</source>
        <translation>&amp;Новое окно</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="338"/>
        <source>&amp;Preferences...</source>
        <translation type="unfinished">&amp;Настройки...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="342"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Выход</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="348"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Спрятать рамку окна</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="359"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Показать панель вкладок</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="367"/>
        <source>Fullscreen</source>
        <translation>Во весь экран</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="373"/>
        <source>Toggle Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="381"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Снизу</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="382"/>
        <source>&amp;Top</source>
        <translation>&amp;Сверху</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="383"/>
        <location filename="../../mainwindow.cpp" line="419"/>
        <source>&amp;Right</source>
        <translation>&amp;Справа</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="384"/>
        <location filename="../../mainwindow.cpp" line="420"/>
        <source>&amp;Left</source>
        <translation>&amp;Слева</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="402"/>
        <source>&amp;Tabs Layout</source>
        <translation>Расположение &amp;вкладок</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="418"/>
        <source>&amp;None</source>
        <translation>&amp;Убрать</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="436"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Расположение по&amp;лосы прокрутки</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="449"/>
        <source>&amp;BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="450"/>
        <source>&amp;UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="451"/>
        <source>&amp;IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="468"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="558"/>
        <source>Exit QTerminal</source>
        <translation>Выйти из QTerminal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="560"/>
        <source>Do not ask again</source>
        <translation>Не спрашивать снова</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="568"/>
        <source>Are you sure you want to exit?</source>
        <translation>Вы уверены, что хотите выйти?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="598"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Лёгкий мультиплатформенный эмулятор терминала</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="432"/>
        <source>Emulation</source>
        <translation>Эмуляция</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="62"/>
        <source>Shortcuts</source>
        <translation>Сочетания клавиш</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Настройки терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="52"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="57"/>
        <location filename="../../forms/propertiesdialog.ui" line="457"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="67"/>
        <source>Dropdown</source>
        <translation>Выпадающий терминал</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="72"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="100"/>
        <source>Color scheme</source>
        <translation>Цветовая схема</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="296"/>
        <source>Widget style</source>
        <translation>Графический стиль</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="110"/>
        <source>Scrollbar position</source>
        <translation>Расположение полосы прокрутки</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="267"/>
        <source>Tabs position</source>
        <translation>Расположение вкладок</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="319"/>
        <source>Show the menu bar</source>
        <translation>Показывать панель меню</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="136"/>
        <source>Show a border around the current terminal</source>
        <translation>Показывать границу вокруг текущего терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="153"/>
        <source>Application transparency</source>
        <translation>Прозрачность приложения</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="143"/>
        <source>Terminal transparency</source>
        <translation>Прозрачность терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="120"/>
        <source>Start with preset:</source>
        <translation>Начинать с предустановкой:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="164"/>
        <source>None (single terminal)</source>
        <translation>Нет (один терминал)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="169"/>
        <source>2 terminals horizontally</source>
        <translation>2 горизонтальных терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="174"/>
        <source>2 terminals vertically</source>
        <translation>2 вертикальных терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="179"/>
        <source>4 terminals</source>
        <translation>4 терминала</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="218"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="326"/>
        <source>Keyboard cursor shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="336"/>
        <source>Change window title based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="343"/>
        <source>Change window icon based on current terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="350"/>
        <source>Enable bi-directional text support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="357"/>
        <source>Background image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="369"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="378"/>
        <source>Show terminal size on resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="385"/>
        <source>Limit tab width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="395"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="405"/>
        <source>Show close button on each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="441"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Какое поведение эмулировать. Обратите внимание, что это не обязательно должно соответствовать вашей операционной системе.&lt;/p&gt;&lt;p&gt;Эмуляция &lt;span style=&quot; font-weight:600;&quot;&gt;по умолчанию&lt;/span&gt; - это запасной режим с минимальным набором функций.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="463"/>
        <source>Action after paste</source>
        <translation>Действие после вставки</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="473"/>
        <source>Confirm multiline paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="480"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="513"/>
        <source>Open new terminals in current working directory</source>
        <translation>Открывать новые терминалы в текущем рабочем каталоге</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="520"/>
        <source>Save Size when closing</source>
        <translation>Запоминать размер при закрытии</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="527"/>
        <source>Save Position when closing</source>
        <translation>Запоминать расположение при закрытии</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="534"/>
        <source>Ask for confirmation when closing</source>
        <translation>Запрашивать подтверждение при закрытии</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="544"/>
        <source>Unlimited history</source>
        <translation>Неограниченная история</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="551"/>
        <source>History size (in lines)</source>
        <translation>Размер истории (в строках)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="558"/>
        <source>Default $TERM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="572"/>
        <source>xterm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="577"/>
        <source>xterm-256color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="649"/>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="659"/>
        <location filename="../../forms/propertiesdialog.ui" line="676"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="666"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="722"/>
        <source>Edit bookmark file contents</source>
        <translation>Изменить содержимое файла закладок</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="744"/>
        <source>Enable bookmarks</source>
        <translation>Включить закладки</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="753"/>
        <source>Bookmark file</source>
        <translation>Файл закладок</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="631"/>
        <source>Show on start</source>
        <translation>Показать при запуске</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="90"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Прятать панель вкладок только с одной вкладкой</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="254"/>
        <source>&amp;Change...</source>
        <translation>&amp;Изменить...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="638"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="690"/>
        <source>Shortcut:</source>
        <translation>Сочетание клавиш:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="766"/>
        <source>Find...</source>
        <translation>Найти...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="775"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Вы можете выбрать ваше собственное место для хранения закладок. Это позволит легко делиться закладками с помощью таких инструментов как OwnCloud или Dropbox.</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="187"/>
        <location filename="../../forms/propertiesdialog.ui" line="280"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="614"/>
        <source>Shortcut</source>
        <translation>Сочетание клавиш</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="619"/>
        <source>Key</source>
        <translation>Клавиши</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <source>No scrollbar</source>
        <translation>Без полосы прокрутки</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>BlockCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>UnderlineCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>IBeamCursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>No move</source>
        <translation>Не двигаться</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move start</source>
        <translation>Переместиться в начало</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move end</source>
        <translation>Переместиться в конец</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="129"/>
        <location filename="../../propertiesdialog.cpp" line="199"/>
        <source>System Default</source>
        <translation>Системный</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="282"/>
        <source>Choose a background image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="283"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="348"/>
        <source>Open or create bookmarks file</source>
        <translation>Открыть или создать файл закладок</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../../termwidget.cpp" line="237"/>
        <source>Show Details...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>Локальные закладки</translation>
    </message>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>Синхронизированные закладки</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../tabwidget.cpp" line="73"/>
        <location filename="../../tabwidget.cpp" line="219"/>
        <source>Shell No. %1</source>
        <translation>Оболочка № %1</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="187"/>
        <source>Tab name</source>
        <translation>Имя вкладки</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="188"/>
        <source>New tab name:</source>
        <translation>Имя новой вкладки:</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="208"/>
        <source>Select new tab title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="229"/>
        <source>Close session</source>
        <translation>Закрыть сессию</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="231"/>
        <source>Change title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename session</source>
        <translation type="vanished">Переименовать сессию</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>Загрузить сессию</translation>
    </message>
    <message>
        <location filename="../../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>Список сохранённых сессий:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../../termwidget.cpp" line="229"/>
        <source>Paste multiline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="230"/>
        <source>Are you sure you want to paste this text?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Главное окно</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Действия</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>О &amp;программе...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>О &amp;Qt...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="vanished">&amp;Настройки...</translation>
    </message>
</context>
</TS>
